--- xmovectrl/xmovectrl.h.orig	1995-01-09 13:02:28.000000000 -0600
+++ xmovectrl/xmovectrl.h	2011-06-13 03:47:06.000000000 -0500
@@ -54,7 +54,6 @@
 
 #include <sys/time.h>
 #include <sys/socket.h>
-#include <malloc.h>
 
 
 Global int pad P((long n ));
